// $Id: StartupExample.cc,v 1.6 2001/10/08 21:36:38 lima Exp $

//###################################################################
//
//      Optical Communication Systems Simulator Example
//
//      For other examples check the personal applications
//      of the current users, such as ocsApp[LastName].cc
//
//      Copyright (2000):
//      Optical Fiber Communications Laboratory (OFCL)
//      Computer Science & Electrical Engineering Department (CSEE)
//      University of Maryland Baltimore County (UMBC)
//
//###################################################################


# include "MyStartup.hh"

extern ofstream LogFile;

StartupExample::StartupExample(string InFileName, int argc, char *argv[])
{


ifstream InFile(InFileName.c_str(),ios::in);    
   
if (!InFile) 
 {
    cerr << "Error: Input file "<< InFileName 
         << " could not be opened."<< endl;
    exit(1);
 }


JobDir = ReadString("JobDir",&InFile);
JobName =  ReadString("JobName",&InFile);

LogFileName = JobDir + JobName + ".log";

 cout << endl
      << "Log File = " << LogFileName << endl << endl;

LogFile.open(LogFileName.c_str(),ios::out);
   
if (!LogFile) 
  {
    cerr << "Error: ocs.log could not be open." << endl << flush;
    exit(1);
  }    

JobPrefix = JobDir + JobName + "_";


LogFileSeparator();
LogFile << InFileName << endl << endl;

LogFile << "Job Prefix = " << JobPrefix << endl;

SimulationType = ReadInt("SimulationType"," ",0,0,NO_BOUNDS,&InFile);
NumMonteCarloExpts = ReadInt("NumMonteCarloExpts"," ",0,-1,LOWER_ONLY,&InFile);
NumMapSpans = ReadInt("NumMapSpans"," ",0,-1,LOWER_ONLY,&InFile);

DebugLevelAmps = ReadInt("DebugLevelAmps"," ",0,3,LOWER_AND_UPPER,
                          OPTIONAL_NO_WARNING,1,&InFile);


RelativeErrorGoal = ReadDouble("RelativeErrorGoal"," ",0,-1,LOWER_ONLY,
                                &InFile);

OutputStepSizesFlag = ReadInt("OutputStepSizes"," ",0,1,
                               LOWER_AND_UPPER,&InFile);


TypeStepSizes = ReadInt("TypeStepSizes"," ",1,4,
                         LOWER_AND_UPPER,OPTIONAL_NO_WARNING,1,&InFile);

if(TypeStepSizes == 3)
  WalkOffParameter = ReadDouble("WalkOffParameter"," ",0,-1,
                                 LOWER_ONLY,MANDATORY,1,&InFile);

Beta3ZeroFlag = ReadInt("Beta3ZeroFlag"," ",0,1,LOWER_AND_UPPER,&InFile);
NonLinearityZeroFlag = ReadInt("NonLinearityZeroFlag"," ",0,1,
                                LOWER_AND_UPPER,&InFile);
FiberLossZeroFlag = ReadInt("FiberLossZeroFlag"," ",0,1,
                             LOWER_AND_UPPER,&InFile);
TypeAmp = ReadInt("TypeAmp"," ",0,5,LOWER_AND_UPPER,&InFile);
AmpsNoiseOffFlag = ReadInt("AmpsNoiseOffFlag"," ",0,1,LOWER_AND_UPPER,&InFile);


bool UseMosixFlag = 1;

if(UseMosixFlag)
  {
   lock_or_unlock_mosix(MOSIX_UNLOCK);
   cpujob_mosix();
   slow_mosix();
  }

InFile.close();

} // end constructor

// #####################################################################
